@@ -65,8 +65,9 @@ def calculate_growth_rates(time, od, window_size=40):
                 r = np.nan
             growth_rates[i] = r
             N0s[i] = N0
-    growth_rates = np.convolve(interpolate_nans(growth_rates), [1 / 120] * 120, mode='same')
 
+    GRwindow = min(120, len(growth_rates))
+    growth_rates = np.convolve(interpolate_nans(growth_rates), [1 / GRwindow] * GRwindow, mode='same')
     return growth_rates, N0s
 
 
